#!/usr/bin/perl
#	update-domains.pl - Execute update-technic.pl for each domain to change
#
# Usage: update-domains.pl [-v] /path-to-info-dir /path-to-key-dir new-nic-handle < whois-output-file

use lib '.';
use Aunic;
use Getopt::Std;

use vars qw/$opt_v/;

getopts('v');

my $info_dir = shift @ARGV || usage();
my $key_dir = shift @ARGV || usage();
my $new_nic_handle = shift @ARGV || usage();

my $update_cmd = "./update-technic.pl";

my @domain_list;

while (<STDIN>) {
	chomp;
	if (/domain:\s+(\S+)/) {
		my $domain = $1;
		my $key;

#		print "Domain is $1\n";
		# Only run the update program if we have all data
		if (!-f "$key_dir/key-$domain") {
			print STDERR "No key file for $domain\n";
			next;
		}

		if (!-f "$info_dir/info-$domain") {
			print STDERR "No key file for $domain\n";
			next;
		}

		# And don't do it if we already have a results file
		if (-f "Results/result-$domain") {
			print STDERR "Already have results for $domain\n";
			next;
		}

		open(K, "<$key_dir/key-$domain");
		my $line = <K>;
		chomp($line);
		if ($line =~ /\S+ (\S+)/) {
			$key = $1;
		}
		close(K);

		if ($key ne '') {
			push(@domain_list, [$domain, $key]);
		} else {
			print "Blank key for $domain\n";
		}
	}
}

if ($opt_v) {
	foreach (sort @domain_list) {
		print "Issue update for $_->[0]\n";
	}

	exit(0);
}

foreach my $r (sort @domain_list) {
	my $domain = $r->[0];
	my $key = $r->[1];

	print "Issuing update for $domain\n";
	system("$update_cmd $domain $info_dir/info-$domain '$key' $new_nic_handle > Results/result-$domain");
}

exit(0);

sub usage {
	die "Usage: update-domains.pl /path-to-info-dir /path-to-key-dir new-nic-handle\n";
}
